# POS Container

This module allows to handle use of reusable containers in POS, this is useful to handle selling product in bulk without having to calculate the tare of the container.

Each container is identified by a barcode, the weight is stored in Odoo.

Table of contents

- Usage
- Bug Tracker
- Credits
  - Authors
  - Contributors
  - Maintainers

# Usage

You have to create a Barcode Nomenclature to handle containers before using the module.

# Bug Tracker

Bugs are tracked on GitHub Issues. In case of trouble, please check there if your issue has already been reported. If you spotted it first, help us smashing it by providing a detailed and welcomed feedback.

Do not contact contributors directly about support or help with technical issues.

# Credits

## Authors

- Coop IT Easy SCRLfs

## Contributors

> - Pierrick Brun <pierrick.brun@akretion.com>
> - Robin Keunen <robin.keunen@coopiteasy.be>

## Maintainers

This module is maintained by the OCA.

OCA, or the Odoo Community Association, is a nonprofit organization whose mission is to support the collaborative development of Odoo features and promote its widespread use.

This module is part of the OCA/pos project on GitHub.

You are welcome to contribute. To learn how please visit https://odoo-community.org/page/Contribute.